PRAGMA foreign_keys=OFF;
BEGIN TRANSACTION;
CREATE TABLE experiment_run (
      run_id INTEGER NOT NULL PRIMARY KEY AUTOINCREMENT,
      created TEXT NOT NULL,
      modified TEXT NOT NULL,
      start INTEGER NOT NULL,
      finish INTEGER,
      chunk_unit TEXT NOT NULL,
      chunk_size INTEGER NOT NULL,
      completed INTEGER NOT NULL,
      total INTEGER NOT NULL,
      failed INTEGER NOT NULL,
      queuing INTEGER NOT NULL,
      running INTEGER NOT NULL,
      submitted INTEGER NOT NULL,
      suspended INTEGER NOT NULL DEFAULT 0,
      metadata TEXT
      );
INSERT INTO experiment_run VALUES(1,'2023-09-12-12:18:55','2023-09-12-12:19:25',1694513935,1694513965,'month',1,0,4,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.89", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "JOBS": {"SYNCHRONIZE": {"FILE": "templates/synchronize.tmpl.sh", "WALLCLOCK": "01:00", "EC_QUEUE": "ecs", "RUNNING": "once", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.tmpl.sh", "DEPENDENCIES": {"SYNCHRONIZE": {}}, "WALLCLOCK": "01:00", "EC_QUEUE": "ecs", "RUNNING": "once", "ADDITIONAL_FILES": []}, "SIM": {"FILE": "templates/sim.tmpl.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}, "SIM-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "01:00", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROJECT": "bsc32", "USER": "bsc32070", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch", "PROJECT": "bsc32", "USER": "bsc32070"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "QUEUE": "bsc_es", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch", "PROJ_DIR": "", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01b", "PROJDIR": "/home/dbeltran/new_autosubmit/a01b/proj/project_files", "DEFAULT": {"EXPID": "a01d", "HPCARCH": "ecmwf-hpc2020", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": "auto-ecearth4"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/es/auto-ecearth4", "PROJECT_BRANCH": "trunk", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true, "SOURCES_REPO": "e7988/ecearth4/-/tree/developments_bsc_autosubmit"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}}');
INSERT INTO experiment_run VALUES(2,'2023-09-12-12:19:25','2023-09-12-12:32:17',1694513965,1694514737,'month',1,0,4,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.89", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "JOBS": {"SYNCHRONIZE": {"FILE": "templates/synchronize.tmpl.sh", "WALLCLOCK": "01:00", "EC_QUEUE": "ecs", "RUNNING": "once", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.tmpl.sh", "DEPENDENCIES": {"SYNCHRONIZE": {}}, "WALLCLOCK": "01:00", "EC_QUEUE": "ecs", "RUNNING": "once", "ADDITIONAL_FILES": []}, "SIM": {"FILE": "templates/sim.tmpl.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}, "SIM-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "01:00", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROJECT": "bsc32", "USER": "bsc32070", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch", "PROJECT": "bsc32", "USER": "bsc32070"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "QUEUE": "bsc_es", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch", "PROJ_DIR": "", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01b", "PROJDIR": "/home/dbeltran/new_autosubmit/a01b/proj/project_files", "DEFAULT": {"EXPID": "a01d", "HPCARCH": "ecmwf-hpc2020", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": "auto-ecearth4"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/es/auto-ecearth4", "PROJECT_BRANCH": "trunk", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true, "SOURCES_REPO": "e7988/ecearth4/-/tree/developments_bsc_autosubmit"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}}');
INSERT INTO experiment_run VALUES(3,'2023-09-12-12:32:17','2023-09-12-12:32:44',1694514737,1694514764,'month',1,0,4,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.89", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "JOBS": {"SYNCHRONIZE": {"FILE": "templates/synchronize.tmpl.sh", "WALLCLOCK": "01:00", "EC_QUEUE": "ecs", "RUNNING": "once", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.tmpl.sh", "DEPENDENCIES": {"SYNCHRONIZE": {}}, "WALLCLOCK": "01:00", "EC_QUEUE": "ecs", "RUNNING": "once", "ADDITIONAL_FILES": []}, "SIM": {"FILE": "templates/sim.tmpl.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}, "SIM-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "01:00", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROJECT": "bsc32", "USER": "bsc32070", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch", "PROJECT": "bsc32", "USER": "bsc32070"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "QUEUE": "bsc_es", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch", "PROJ_DIR": "", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread", "PROJECT": "spesiccf"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01b", "PROJDIR": "/home/dbeltran/new_autosubmit/a01b/proj/project_files", "DEFAULT": {"EXPID": "a01d", "HPCARCH": "ecmwf-hpc2020", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": "auto-ecearth4"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/es/auto-ecearth4", "PROJECT_BRANCH": "trunk", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true, "SOURCES_REPO": "e7988/ecearth4/-/tree/developments_bsc_autosubmit"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}}');
INSERT INTO experiment_run VALUES(4,'2023-09-12-12:32:44','2023-09-12-12:37:44',1694514764,1694515064,'month',1,0,4,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.89", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "JOBS": {"SYNCHRONIZE": {"FILE": "templates/synchronize.tmpl.sh", "WALLCLOCK": "01:00", "EC_QUEUE": "ecs", "RUNNING": "once", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.tmpl.sh", "DEPENDENCIES": {"SYNCHRONIZE": {}}, "WALLCLOCK": "01:00", "EC_QUEUE": "ecs", "RUNNING": "once", "ADDITIONAL_FILES": []}, "SIM": {"FILE": "templates/sim.tmpl.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}, "SIM-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "01:00", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROJECT": "bsc32", "USER": "bsc32070", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch", "PROJECT": "bsc32", "USER": "bsc32070"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "QUEUE": "bsc_es", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch", "PROJ_DIR": "", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread", "PROJECT": "spesiccf"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01b", "PROJDIR": "/home/dbeltran/new_autosubmit/a01b/proj/project_files", "DEFAULT": {"EXPID": "a01d", "HPCARCH": "ecmwf-hpc2020", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": "auto-ecearth4"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/es/auto-ecearth4", "PROJECT_BRANCH": "trunk", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true, "SOURCES_REPO": "e7988/ecearth4/-/tree/developments_bsc_autosubmit"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}}');
INSERT INTO experiment_run VALUES(5,'2023-09-12-12:37:44','2023-09-12-12:39:03',1694515064,1694515143,'month',1,0,4,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.89", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "JOBS": {"SYNCHRONIZE": {"FILE": "templates/synchronize.tmpl.sh", "WALLCLOCK": "01:00", "EC_QUEUE": "ecs", "RUNNING": "once", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.tmpl.sh", "DEPENDENCIES": {"SYNCHRONIZE": {}}, "WALLCLOCK": "01:00", "EC_QUEUE": "ecs", "RUNNING": "once", "ADDITIONAL_FILES": []}, "SIM": {"FILE": "templates/sim.tmpl.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}, "SIM-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "01:00", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROJECT": "bsc32", "USER": "bsc32070", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch", "PROJECT": "bsc32", "USER": "bsc32070"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "QUEUE": "bsc_es", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch", "PROJ_DIR": "", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread", "PROJECT": "spesiccf"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01b", "PROJDIR": "/home/dbeltran/new_autosubmit/a01b/proj/project_files", "DEFAULT": {"EXPID": "a01d", "HPCARCH": "ecmwf-hpc2020", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": "auto-ecearth4"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/es/auto-ecearth4", "PROJECT_BRANCH": "trunk", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true, "SOURCES_REPO": "e7988/ecearth4/-/tree/developments_bsc_autosubmit"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}}');
INSERT INTO experiment_run VALUES(6,'2023-09-12-12:39:03','2023-09-12-12:39:57',1694515143,1694515197,'month',1,0,4,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.89", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "JOBS": {"SYNCHRONIZE": {"FILE": "templates/synchronize.tmpl.sh", "WALLCLOCK": "01:00", "EC_QUEUE": "ecs", "RUNNING": "once", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.tmpl.sh", "DEPENDENCIES": {"SYNCHRONIZE": {}}, "WALLCLOCK": "01:00", "EC_QUEUE": "ecs", "RUNNING": "once", "ADDITIONAL_FILES": []}, "SIM": {"FILE": "templates/sim.tmpl.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}, "SIM-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "01:00", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROJECT": "bsc32", "USER": "bsc32070", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch", "PROJECT": "bsc32", "USER": "bsc32070"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "QUEUE": "bsc_es", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch", "PROJ_DIR": "", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread", "PROJECT": "spesiccf"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01b", "PROJDIR": "/home/dbeltran/new_autosubmit/a01b/proj/project_files", "DEFAULT": {"EXPID": "a01d", "HPCARCH": "ecmwf-hpc2020", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": "auto-ecearth4"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/es/auto-ecearth4", "PROJECT_BRANCH": "trunk", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true, "SOURCES_REPO": "e7988/ecearth4/-/tree/developments_bsc_autosubmit"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}}');
INSERT INTO experiment_run VALUES(7,'2023-09-12-12:39:57','2023-09-12-12:41:06',1694515197,1694515266,'month',1,0,4,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.89", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "JOBS": {"SYNCHRONIZE": {"FILE": "templates/synchronize.tmpl.sh", "WALLCLOCK": "01:00", "EC_QUEUE": "ecs", "RUNNING": "once", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.tmpl.sh", "DEPENDENCIES": {"SYNCHRONIZE": {}}, "WALLCLOCK": "01:00", "EC_QUEUE": "ecs", "RUNNING": "once", "ADDITIONAL_FILES": []}, "SIM": {"FILE": "templates/sim.tmpl.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}, "SIM-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "01:00", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROJECT": "bsc32", "USER": "bsc32070", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch", "PROJECT": "bsc32", "USER": "bsc32070"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "QUEUE": "bsc_es", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch", "PROJ_DIR": "", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread", "PROJECT": "spesiccf"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01b", "PROJDIR": "/home/dbeltran/new_autosubmit/a01b/proj/project_files", "DEFAULT": {"EXPID": "a01d", "HPCARCH": "ecmwf-hpc2020", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": "auto-ecearth4"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/es/auto-ecearth4", "PROJECT_BRANCH": "trunk", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true, "SOURCES_REPO": "e7988/ecearth4/-/tree/developments_bsc_autosubmit"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}}');
INSERT INTO experiment_run VALUES(8,'2023-09-12-12:41:06','2023-09-12-12:42:53',1694515266,1694515373,'month',1,0,4,0,1,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.89", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "JOBS": {"SYNCHRONIZE": {"FILE": "templates/synchronize.tmpl.sh", "WALLCLOCK": "01:00", "EC_QUEUE": "ecs", "RUNNING": "once", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.tmpl.sh", "DEPENDENCIES": {"SYNCHRONIZE": {}}, "WALLCLOCK": "01:00", "EC_QUEUE": "ecs", "RUNNING": "once", "ADDITIONAL_FILES": []}, "SIM": {"FILE": "templates/sim.tmpl.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}, "SIM-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "01:00", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROJECT": "bsc32", "USER": "bsc32070", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch", "PROJECT": "bsc32", "USER": "bsc32070"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "QUEUE": "bsc_es", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJ_DIR": "", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread", "PROJECT": "spesiccf"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01b", "PROJDIR": "/home/dbeltran/new_autosubmit/a01b/proj/project_files", "DEFAULT": {"EXPID": "a01d", "HPCARCH": "ecmwf-hpc2020", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": "auto-ecearth4"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/es/auto-ecearth4", "PROJECT_BRANCH": "trunk", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true, "SOURCES_REPO": "e7988/ecearth4/-/tree/developments_bsc_autosubmit"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}}');
INSERT INTO experiment_run VALUES(9,'2023-09-12-12:42:53','2023-09-12-12:54:15',1694515373,1694516055,'month',1,0,4,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.89", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "JOBS": {"SYNCHRONIZE": {"FILE": "templates/synchronize.tmpl.sh", "WALLCLOCK": "01:00", "EC_QUEUE": "ecs", "RUNNING": "once", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.tmpl.sh", "DEPENDENCIES": {"SYNCHRONIZE": {}}, "WALLCLOCK": "01:00", "EC_QUEUE": "ecs", "RUNNING": "once", "ADDITIONAL_FILES": []}, "SIM": {"FILE": "templates/sim.tmpl.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}, "SIM-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "01:00", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROJECT": "bsc32", "USER": "bsc32070", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch", "PROJECT": "bsc32", "USER": "bsc32070"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "QUEUE": "bsc_es", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJ_DIR": "", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread", "PROJECT": "spesiccf"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01b", "PROJDIR": "/home/dbeltran/new_autosubmit/a01b/proj/project_files", "DEFAULT": {"EXPID": "a01d", "HPCARCH": "ecmwf-hpc2020", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": "auto-ecearth4"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/es/auto-ecearth4", "PROJECT_BRANCH": "trunk", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true, "SOURCES_REPO": "e7988/ecearth4/-/tree/developments_bsc_autosubmit"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}}');
INSERT INTO experiment_run VALUES(10,'2023-09-12-12:54:15','2023-09-12-12:58:53',1694516055,1694516333,'month',1,0,4,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.89", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "JOBS": {"SYNCHRONIZE": {"FILE": "templates/synchronize.tmpl.sh", "WALLCLOCK": "01:00", "EC_QUEUE": "ecs", "RUNNING": "once", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.tmpl.sh", "DEPENDENCIES": {"SYNCHRONIZE": {}}, "WALLCLOCK": "01:00", "EC_QUEUE": "ecs", "RUNNING": "once", "ADDITIONAL_FILES": []}, "SIM": {"FILE": "templates/sim.tmpl.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}, "SIM-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "01:00", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROJECT": "bsc32", "USER": "bsc32070", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch", "PROJECT": "bsc32", "USER": "bsc32070"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "QUEUE": "bsc_es", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJ_DIR": "", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread", "PROJECT": "spesiccf"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01b", "PROJDIR": "/home/dbeltran/new_autosubmit/a01b/proj/project_files", "DEFAULT": {"EXPID": "a01d", "HPCARCH": "ecmwf-hpc2020", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": "auto-ecearth4"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/es/auto-ecearth4", "PROJECT_BRANCH": "trunk", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true, "SOURCES_REPO": "e7988/ecearth4/-/tree/developments_bsc_autosubmit"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}}');
INSERT INTO experiment_run VALUES(11,'2023-09-12-12:58:53','2023-09-12-13:06:34',1694516333,1694516794,'month',1,0,4,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.89", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "JOBS": {"SYNCHRONIZE": {"FILE": "templates/synchronize.tmpl.sh", "WALLCLOCK": "01:00", "EC_QUEUE": "ecs", "RUNNING": "once", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.tmpl.sh", "DEPENDENCIES": {"SYNCHRONIZE": {}}, "WALLCLOCK": "01:00", "EC_QUEUE": "ecs", "RUNNING": "once", "ADDITIONAL_FILES": []}, "SIM": {"FILE": "templates/sim.tmpl.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}, "SIM-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "01:00", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROJECT": "bsc32", "USER": "bsc32070", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch", "PROJECT": "bsc32", "USER": "bsc32070"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "QUEUE": "bsc_es", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJ_DIR": "", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread", "SCRATCH_PROJECT_DIR": "/ec/res4/scratch/c3d", "PROJECT": "spesiccf"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01b", "PROJDIR": "/home/dbeltran/new_autosubmit/a01b/proj/project_files", "DEFAULT": {"EXPID": "a01d", "HPCARCH": "ecmwf-hpc2020", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": "auto-ecearth4"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/es/auto-ecearth4", "PROJECT_BRANCH": "trunk", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true, "SOURCES_REPO": "e7988/ecearth4/-/tree/developments_bsc_autosubmit"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}}');
INSERT INTO experiment_run VALUES(12,'2023-09-12-13:06:34','2023-09-12-13:08:42',1694516794,1694516922,'month',1,0,4,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.89", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "JOBS": {"SYNCHRONIZE": {"FILE": "templates/synchronize.tmpl.sh", "WALLCLOCK": "01:00", "EC_QUEUE": "ecs", "RUNNING": "once", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.tmpl.sh", "DEPENDENCIES": {"SYNCHRONIZE": {}}, "WALLCLOCK": "01:00", "EC_QUEUE": "ecs", "RUNNING": "once", "ADDITIONAL_FILES": []}, "SIM": {"FILE": "templates/sim.tmpl.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}, "SIM-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "01:00", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROJECT": "bsc32", "USER": "bsc32070", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch", "PROJECT": "bsc32", "USER": "bsc32070"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "QUEUE": "bsc_es", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJ_DIR": "", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread", "SCRATCH_PROJECT_DIR": "", "PROJECT": "spesiccf"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01b", "PROJDIR": "/home/dbeltran/new_autosubmit/a01b/proj/project_files", "DEFAULT": {"EXPID": "a01d", "HPCARCH": "ecmwf-hpc2020", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": "auto-ecearth4"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/es/auto-ecearth4", "PROJECT_BRANCH": "trunk", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true, "SOURCES_REPO": "e7988/ecearth4/-/tree/developments_bsc_autosubmit"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}}');
INSERT INTO experiment_run VALUES(13,'2023-09-12-13:08:42','2023-09-12-13:12:27',1694516922,1694517147,'month',1,0,4,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.89", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "JOBS": {"SYNCHRONIZE": {"FILE": "templates/synchronize.tmpl.sh", "WALLCLOCK": "01:00", "EC_QUEUE": "ecs", "RUNNING": "once", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.tmpl.sh", "DEPENDENCIES": {"SYNCHRONIZE": {}}, "WALLCLOCK": "01:00", "EC_QUEUE": "ecs", "RUNNING": "once", "ADDITIONAL_FILES": []}, "SIM": {"FILE": "templates/sim.tmpl.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}, "SIM-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "01:00", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROJECT": "bsc32", "USER": "bsc32070", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch", "PROJECT": "bsc32", "USER": "bsc32070"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "QUEUE": "bsc_es", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/", "PROJ_DIR": "", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread", "SCRATCH_PROJECT_DIR": "c3d", "PROJECT": "spesiccf"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01b", "PROJDIR": "/home/dbeltran/new_autosubmit/a01b/proj/project_files", "DEFAULT": {"EXPID": "a01d", "HPCARCH": "ecmwf-hpc2020", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": "auto-ecearth4"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/es/auto-ecearth4", "PROJECT_BRANCH": "trunk", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true, "SOURCES_REPO": "e7988/ecearth4/-/tree/developments_bsc_autosubmit"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}}');
INSERT INTO experiment_run VALUES(14,'2023-09-12-13:12:27','2023-09-12-13:12:31',1694517147,1694517151,'month',1,0,4,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.89", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "JOBS": {"SYNCHRONIZE": {"FILE": "templates/synchronize.tmpl.sh", "WALLCLOCK": "01:00", "EC_QUEUE": "ecs", "RUNNING": "once", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.tmpl.sh", "DEPENDENCIES": {"SYNCHRONIZE": {}}, "WALLCLOCK": "01:00", "EC_QUEUE": "ecs", "RUNNING": "once", "ADDITIONAL_FILES": []}, "SIM": {"FILE": "templates/sim.tmpl.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}, "SIM-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "01:00", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROJECT": "bsc32", "USER": "bsc32070", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch", "PROJECT": "bsc32", "USER": "bsc32070"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "QUEUE": "bsc_es", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/", "PROJ_DIR": "", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread", "SCRATCH_PROJECT_DIR": "c3d", "PROJECT": "spesiccf"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01b", "PROJDIR": "/home/dbeltran/new_autosubmit/a01b/proj/project_files", "DEFAULT": {"EXPID": "a01d", "HPCARCH": "ecmwf-hpc2020", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": "auto-ecearth4"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/es/auto-ecearth4", "PROJECT_BRANCH": "trunk", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true, "SOURCES_REPO": "e7988/ecearth4/-/tree/developments_bsc_autosubmit"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}}');
INSERT INTO experiment_run VALUES(15,'2023-09-12-13:12:31','2023-09-12-13:13:04',1694517151,1694517184,'month',1,0,4,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.89", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "JOBS": {"SYNCHRONIZE": {"FILE": "templates/synchronize.tmpl.sh", "WALLCLOCK": "01:00", "EC_QUEUE": "ecs", "RUNNING": "once", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.tmpl.sh", "DEPENDENCIES": {"SYNCHRONIZE": {}}, "WALLCLOCK": "01:00", "EC_QUEUE": "ecs", "RUNNING": "once", "ADDITIONAL_FILES": []}, "SIM": {"FILE": "templates/sim.tmpl.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}, "SIM-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "01:00", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROJECT": "bsc32", "USER": "bsc32070", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch", "PROJECT": "bsc32", "USER": "bsc32070"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "QUEUE": "bsc_es", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/", "PROJ_DIR": "", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread", "SCRATCH_PROJECT_DIR": "c3d", "PROJECT": "spesiccf"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01b", "PROJDIR": "/home/dbeltran/new_autosubmit/a01b/proj/project_files", "DEFAULT": {"EXPID": "a01d", "HPCARCH": "ecmwf-hpc2020", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": "auto-ecearth4"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/es/auto-ecearth4", "PROJECT_BRANCH": "trunk", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true, "SOURCES_REPO": "e7988/ecearth4/-/tree/developments_bsc_autosubmit"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}}');
INSERT INTO experiment_run VALUES(16,'2023-09-12-13:13:04','2023-09-12-13:13:09',1694517184,1694517189,'month',1,0,4,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.89", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "JOBS": {"SYNCHRONIZE": {"FILE": "templates/synchronize.tmpl.sh", "WALLCLOCK": "01:00", "EC_QUEUE": "ecs", "RUNNING": "once", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.tmpl.sh", "DEPENDENCIES": {"SYNCHRONIZE": {}}, "WALLCLOCK": "01:00", "EC_QUEUE": "ecs", "RUNNING": "once", "ADDITIONAL_FILES": []}, "SIM": {"FILE": "templates/sim.tmpl.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}, "SIM-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "01:00", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROJECT": "bsc32", "USER": "bsc32070", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch", "PROJECT": "bsc32", "USER": "bsc32070"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "QUEUE": "bsc_es", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJ_DIR": "", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread", "PROJECT": "spesiccf"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01b", "PROJDIR": "/home/dbeltran/new_autosubmit/a01b/proj/project_files", "DEFAULT": {"EXPID": "a01d", "HPCARCH": "ecmwf-hpc2020", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": "auto-ecearth4"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/es/auto-ecearth4", "PROJECT_BRANCH": "trunk", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true, "SOURCES_REPO": "e7988/ecearth4/-/tree/developments_bsc_autosubmit"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}}');
INSERT INTO experiment_run VALUES(17,'2023-09-12-13:13:09','2023-09-12-13:14:28',1694517189,1694517268,'month',1,0,4,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.89", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "JOBS": {"SYNCHRONIZE": {"FILE": "templates/synchronize.tmpl.sh", "WALLCLOCK": "01:00", "EC_QUEUE": "ecs", "RUNNING": "once", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.tmpl.sh", "DEPENDENCIES": {"SYNCHRONIZE": {}}, "WALLCLOCK": "01:00", "EC_QUEUE": "ecs", "RUNNING": "once", "ADDITIONAL_FILES": []}, "SIM": {"FILE": "templates/sim.tmpl.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}, "SIM-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "01:00", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROJECT": "bsc32", "USER": "bsc32070", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch", "PROJECT": "bsc32", "USER": "bsc32070"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "QUEUE": "bsc_es", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJ_DIR": "", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread", "PROJECT": "spesiccf"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01b", "PROJDIR": "/home/dbeltran/new_autosubmit/a01b/proj/project_files", "DEFAULT": {"EXPID": "a01d", "HPCARCH": "ecmwf-hpc2020", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": "auto-ecearth4"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/es/auto-ecearth4", "PROJECT_BRANCH": "trunk", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true, "SOURCES_REPO": "e7988/ecearth4/-/tree/developments_bsc_autosubmit"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}}');
INSERT INTO experiment_run VALUES(18,'2023-09-12-13:14:28','2023-09-12-13:26:56',1694517268,1694518016,'month',1,0,4,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.89", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "JOBS": {"SYNCHRONIZE": {"FILE": "templates/synchronize.tmpl.sh", "WALLCLOCK": "01:00", "EC_QUEUE": "ecs", "RUNNING": "once", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.tmpl.sh", "DEPENDENCIES": {"SYNCHRONIZE": {}}, "WALLCLOCK": "01:00", "EC_QUEUE": "ecs", "RUNNING": "once", "ADDITIONAL_FILES": []}, "SIM": {"FILE": "templates/sim.tmpl.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}, "SIM-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "01:00", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROJECT": "bsc32", "USER": "bsc32070", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch", "PROJECT": "bsc32", "USER": "bsc32070"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "QUEUE": "bsc_es", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJ_DIR": "", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread", "PROJECT": "spesiccf"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01b", "PROJDIR": "/home/dbeltran/new_autosubmit/a01b/proj/project_files", "DEFAULT": {"EXPID": "a01d", "HPCARCH": "ecmwf-hpc2020", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": "auto-ecearth4"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/es/auto-ecearth4", "PROJECT_BRANCH": "trunk", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true, "SOURCES_REPO": "e7988/ecearth4/-/tree/developments_bsc_autosubmit"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}}');
INSERT INTO experiment_run VALUES(19,'2023-09-12-13:26:56','2023-09-12-13:27:23',1694518016,1694518043,'month',1,0,4,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.89", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "JOBS": {"SYNCHRONIZE": {"FILE": "templates/synchronize.tmpl.sh", "WALLCLOCK": "01:00", "EC_QUEUE": "ecs", "RUNNING": "once", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.tmpl.sh", "DEPENDENCIES": {"SYNCHRONIZE": {}}, "WALLCLOCK": "01:00", "EC_QUEUE": "ecs", "RUNNING": "once", "ADDITIONAL_FILES": []}, "SIM": {"FILE": "templates/sim.tmpl.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}, "SIM-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "01:00", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROJECT": "bsc32", "USER": "bsc32070", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch", "PROJECT": "bsc32", "USER": "bsc32070"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "QUEUE": "bsc_es", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJ_DIR": "", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread", "PROJECT": "spesiccf"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01b", "PROJDIR": "/home/dbeltran/new_autosubmit/a01b/proj/project_files", "DEFAULT": {"EXPID": "a01d", "HPCARCH": "ecmwf-hpc2020", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": "auto-ecearth4"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/es/auto-ecearth4", "PROJECT_BRANCH": "trunk", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true, "SOURCES_REPO": "e7988/ecearth4/-/tree/developments_bsc_autosubmit"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}}');
INSERT INTO experiment_run VALUES(20,'2023-09-12-13:27:23','2023-09-12-13:28:31',1694518043,1694518111,'month',1,0,4,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.89", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "JOBS": {"SYNCHRONIZE": {"FILE": "templates/synchronize.tmpl.sh", "WALLCLOCK": "01:00", "EC_QUEUE": "ecs", "RUNNING": "once", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.tmpl.sh", "DEPENDENCIES": {"SYNCHRONIZE": {}}, "WALLCLOCK": "01:00", "EC_QUEUE": "ecs", "RUNNING": "once", "ADDITIONAL_FILES": []}, "SIM": {"FILE": "templates/sim.tmpl.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}, "SIM-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "01:00", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROJECT": "bsc32", "USER": "bsc32070", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch", "PROJECT": "bsc32", "USER": "bsc32070"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "QUEUE": "bsc_es", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJ_DIR": "", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread", "PROJECT": "spesiccf"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01b", "PROJDIR": "/home/dbeltran/new_autosubmit/a01b/proj/project_files", "DEFAULT": {"EXPID": "a01d", "HPCARCH": "ecmwf-hpc2020", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": "auto-ecearth4"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/es/auto-ecearth4", "PROJECT_BRANCH": "trunk", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true, "SOURCES_REPO": "e7988/ecearth4/-/tree/developments_bsc_autosubmit"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}}');
INSERT INTO experiment_run VALUES(21,'2023-09-12-13:28:31','2023-09-12-13:40:57',1694518111,1694518857,'month',1,0,4,0,1,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.89", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "JOBS": {"SYNCHRONIZE": {"FILE": "templates/synchronize.tmpl.sh", "WALLCLOCK": "01:00", "EC_QUEUE": "ecs", "RUNNING": "once", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.tmpl.sh", "DEPENDENCIES": {"SYNCHRONIZE": {}}, "WALLCLOCK": "01:00", "EC_QUEUE": "ecs", "RUNNING": "once", "ADDITIONAL_FILES": []}, "SIM": {"FILE": "templates/sim.tmpl.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}, "SIM-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "01:00", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROJECT": "bsc32", "USER": "bsc32070", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch", "PROJECT": "bsc32", "USER": "bsc32070"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "QUEUE": "bsc_es", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJ_DIR": "", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread", "PROJECT": "spesiccf"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01b", "PROJDIR": "/home/dbeltran/new_autosubmit/a01b/proj/project_files", "DEFAULT": {"EXPID": "a01d", "HPCARCH": "ecmwf-hpc2020", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": "auto-ecearth4"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/es/auto-ecearth4", "PROJECT_BRANCH": "trunk", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true, "SOURCES_REPO": "e7988/ecearth4/-/tree/developments_bsc_autosubmit"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}}');
INSERT INTO experiment_run VALUES(22,'2023-09-12-13:40:57','2023-09-12-13:42:42',1694518857,1694518962,'month',1,0,4,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.89", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "JOBS": {"SYNCHRONIZE": {"FILE": "templates/synchronize.tmpl.sh", "WALLCLOCK": "01:00", "EC_QUEUE": "ecs", "RUNNING": "once", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.tmpl.sh", "DEPENDENCIES": {"SYNCHRONIZE": {}}, "WALLCLOCK": "01:00", "EC_QUEUE": "ecs", "RUNNING": "once", "ADDITIONAL_FILES": []}, "SIM": {"FILE": "templates/sim.tmpl.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}, "SIM-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "01:00", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROJECT": "bsc32", "USER": "bsc32070", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch", "PROJECT": "bsc32", "USER": "bsc32070"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "QUEUE": "bsc_es", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJ_DIR": "", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread", "PROJECT": "spesiccf"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01b", "PROJDIR": "/home/dbeltran/new_autosubmit/a01b/proj/project_files", "DEFAULT": {"EXPID": "a01d", "HPCARCH": "ecmwf-hpc2020", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": "auto-ecearth4"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/es/auto-ecearth4", "PROJECT_BRANCH": "trunk", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true, "SOURCES_REPO": "e7988/ecearth4/-/tree/developments_bsc_autosubmit"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}}');
INSERT INTO experiment_run VALUES(23,'2023-09-12-13:42:42','2023-09-12-13:42:44',1694518962,1694518964,'month',1,0,4,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.89", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "JOBS": {"SYNCHRONIZE": {"FILE": "templates/synchronize.tmpl.sh", "WALLCLOCK": "01:00", "EC_QUEUE": "ecs", "RUNNING": "once", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.tmpl.sh", "DEPENDENCIES": {"SYNCHRONIZE": {}}, "WALLCLOCK": "01:00", "EC_QUEUE": "ecs", "RUNNING": "once", "ADDITIONAL_FILES": []}, "SIM": {"FILE": "templates/sim.tmpl.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}, "SIM-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "01:00", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROJECT": "bsc32", "USER": "bsc32070", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch", "PROJECT": "bsc32", "USER": "bsc32070"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "QUEUE": "bsc_es", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJ_DIR": "", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread", "PROJECT": "spesiccf"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01b", "PROJDIR": "/home/dbeltran/new_autosubmit/a01b/proj/project_files", "DEFAULT": {"EXPID": "a01d", "HPCARCH": "ecmwf-hpc2020", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": "auto-ecearth4"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/es/auto-ecearth4", "PROJECT_BRANCH": "trunk", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true, "SOURCES_REPO": "e7988/ecearth4/-/tree/developments_bsc_autosubmit"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}}');
INSERT INTO experiment_run VALUES(24,'2023-09-12-13:42:44','2023-09-12-13:47:36',1694518964,1694519256,'month',1,0,4,0,0,1,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.89", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "JOBS": {"SYNCHRONIZE": {"FILE": "templates/synchronize.tmpl.sh", "WALLCLOCK": "01:00", "EC_QUEUE": "ecs", "RUNNING": "once", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.tmpl.sh", "DEPENDENCIES": {"SYNCHRONIZE": {}}, "WALLCLOCK": "01:00", "EC_QUEUE": "ecs", "RUNNING": "once", "ADDITIONAL_FILES": []}, "SIM": {"FILE": "templates/sim.tmpl.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}, "SIM-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "01:00", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROJECT": "bsc32", "USER": "bsc32070", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch", "PROJECT": "bsc32", "USER": "bsc32070"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "QUEUE": "bsc_es", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJ_DIR": "", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread", "PROJECT": "spesiccf"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01b", "PROJDIR": "/home/dbeltran/new_autosubmit/a01b/proj/project_files", "DEFAULT": {"EXPID": "a01d", "HPCARCH": "ecmwf-hpc2020", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": "auto-ecearth4"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/es/auto-ecearth4", "PROJECT_BRANCH": "trunk", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true, "SOURCES_REPO": "e7988/ecearth4/-/tree/developments_bsc_autosubmit"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}}');
INSERT INTO experiment_run VALUES(25,'2023-09-12-13:47:36','2023-09-12-13:49:06',1694519256,1694519346,'month',1,0,4,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.89", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "JOBS": {"SYNCHRONIZE": {"FILE": "templates/synchronize.tmpl.sh", "WALLCLOCK": "01:00", "EC_QUEUE": "ecs", "RUNNING": "once", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.tmpl.sh", "DEPENDENCIES": {"SYNCHRONIZE": {}}, "WALLCLOCK": "01:00", "EC_QUEUE": "ecs", "RUNNING": "once", "ADDITIONAL_FILES": []}, "SIM": {"FILE": "templates/sim.tmpl.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}, "SIM-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "01:00", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROJECT": "bsc32", "USER": "bsc32070", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch", "PROJECT": "bsc32", "USER": "bsc32070"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "QUEUE": "bsc_es", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJ_DIR": "", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread", "PROJECT": "spesiccf"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01b", "PROJDIR": "/home/dbeltran/new_autosubmit/a01b/proj/project_files", "DEFAULT": {"EXPID": "a01d", "HPCARCH": "ecmwf-hpc2020", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": "auto-ecearth4"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/es/auto-ecearth4", "PROJECT_BRANCH": "trunk", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true, "SOURCES_REPO": "e7988/ecearth4/-/tree/developments_bsc_autosubmit"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}}');
INSERT INTO experiment_run VALUES(26,'2023-09-12-13:49:06','2023-09-12-13:50:02',1694519346,1694519402,'month',1,0,4,0,1,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.89", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "JOBS": {"SYNCHRONIZE": {"FILE": "templates/synchronize.tmpl.sh", "WALLCLOCK": "01:00", "EC_QUEUE": "ecs", "RUNNING": "once", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.tmpl.sh", "DEPENDENCIES": {"SYNCHRONIZE": {}}, "WALLCLOCK": "01:00", "EC_QUEUE": "ecs", "RUNNING": "once", "ADDITIONAL_FILES": []}, "SIM": {"FILE": "templates/sim.tmpl.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}, "SIM-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "01:00", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROJECT": "bsc32", "USER": "bsc32070", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch", "PROJECT": "bsc32", "USER": "bsc32070"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "QUEUE": "bsc_es", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJ_DIR": "", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread", "PROJECT": "spesiccf"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01b", "PROJDIR": "/home/dbeltran/new_autosubmit/a01b/proj/project_files", "DEFAULT": {"EXPID": "a01d", "HPCARCH": "ecmwf-hpc2020", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": "auto-ecearth4"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/es/auto-ecearth4", "PROJECT_BRANCH": "trunk", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true, "SOURCES_REPO": "e7988/ecearth4/-/tree/developments_bsc_autosubmit"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}}');
INSERT INTO experiment_run VALUES(27,'2023-09-12-13:50:02','2023-09-12-14:48:12',1694519402,1694522892,'month',1,0,4,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.89", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "JOBS": {"SYNCHRONIZE": {"FILE": "templates/synchronize.tmpl.sh", "WALLCLOCK": "01:00", "EC_QUEUE": "ecs", "RUNNING": "once", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.tmpl.sh", "DEPENDENCIES": {"SYNCHRONIZE": {}}, "WALLCLOCK": "01:00", "EC_QUEUE": "ecs", "RUNNING": "once", "ADDITIONAL_FILES": []}, "SIM": {"FILE": "templates/sim.tmpl.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}, "SIM-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "01:00", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROJECT": "bsc32", "USER": "bsc32070", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch", "PROJECT": "bsc32", "USER": "bsc32070"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "QUEUE": "bsc_es", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJ_DIR": "", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread", "PROJECT": "spesiccf"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01b", "PROJDIR": "/home/dbeltran/new_autosubmit/a01b/proj/project_files", "DEFAULT": {"EXPID": "a01d", "HPCARCH": "ecmwf-hpc2020", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": "auto-ecearth4"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/es/auto-ecearth4", "PROJECT_BRANCH": "trunk", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true, "SOURCES_REPO": "e7988/ecearth4/-/tree/developments_bsc_autosubmit"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}}');
INSERT INTO experiment_run VALUES(28,'2023-09-12-14:48:12','2023-09-12-14:48:14',1694522892,1694522894,'month',1,0,4,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.89", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "JOBS": {"SYNCHRONIZE": {"FILE": "templates/synchronize.tmpl.sh", "WALLCLOCK": "01:00", "EC_QUEUE": "ecs", "RUNNING": "once", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.tmpl.sh", "DEPENDENCIES": {"SYNCHRONIZE": {}}, "WALLCLOCK": "01:00", "EC_QUEUE": "ecs", "RUNNING": "once", "ADDITIONAL_FILES": []}, "SIM": {"FILE": "templates/sim.tmpl.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}, "SIM-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "01:00", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROJECT": "bsc32", "USER": "bsc32070", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch", "PROJECT": "bsc32", "USER": "bsc32070"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "QUEUE": "bsc_es", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJ_DIR": "", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread", "PROJECT": "spesiccf"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01b", "PROJDIR": "/home/dbeltran/new_autosubmit/a01b/proj/project_files", "DEFAULT": {"EXPID": "a01d", "HPCARCH": "ecmwf-hpc2020", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": "auto-ecearth4"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/es/auto-ecearth4", "PROJECT_BRANCH": "trunk", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true, "SOURCES_REPO": "e7988/ecearth4/-/tree/developments_bsc_autosubmit"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}}');
INSERT INTO experiment_run VALUES(29,'2023-09-12-14:48:14','2023-09-12-15:19:08',1694522894,1694524748,'month',1,0,4,1,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.89", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "JOBS": {"SYNCHRONIZE": {"FILE": "templates/synchronize.tmpl.sh", "WALLCLOCK": "01:00", "EC_QUEUE": "ecs", "RUNNING": "once", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.tmpl.sh", "DEPENDENCIES": {"SYNCHRONIZE": {}}, "WALLCLOCK": "01:00", "EC_QUEUE": "ecs", "RUNNING": "once", "ADDITIONAL_FILES": []}, "SIM": {"FILE": "templates/sim.tmpl.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}, "SIM-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "01:00", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROJECT": "bsc32", "USER": "bsc32070", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch", "PROJECT": "bsc32", "USER": "bsc32070"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "QUEUE": "bsc_es", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJ_DIR": "", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread", "PROJECT": "spesiccf"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01b", "PROJDIR": "/home/dbeltran/new_autosubmit/a01b/proj/project_files", "DEFAULT": {"EXPID": "a01d", "HPCARCH": "ecmwf-hpc2020", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": "auto-ecearth4"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/es/auto-ecearth4", "PROJECT_BRANCH": "trunk", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true, "SOURCES_REPO": "e7988/ecearth4/-/tree/developments_bsc_autosubmit"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}}');
INSERT INTO experiment_run VALUES(30,'2023-09-12-15:19:08','2023-09-12-15:26:01',1694524748,1694525161,'month',1,1,4,0,0,1,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.89", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "JOBS": {"SYNCHRONIZE": {"FILE": "templates/synchronize.tmpl.sh", "WALLCLOCK": "01:00", "EC_QUEUE": "ecs", "RUNNING": "once", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.tmpl.sh", "DEPENDENCIES": {"SYNCHRONIZE": {}}, "WALLCLOCK": "01:00", "EC_QUEUE": "ecs", "RUNNING": "once", "ADDITIONAL_FILES": []}, "SIM": {"FILE": "templates/sim.tmpl.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}, "SIM-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "01:00", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROJECT": "bsc32", "USER": "bsc32070", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch", "PROJECT": "bsc32", "USER": "bsc32070"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "QUEUE": "bsc_es", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJ_DIR": "", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread", "PROJECT": "spesiccf"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01b", "PROJDIR": "/home/dbeltran/new_autosubmit/a01b/proj/project_files", "DEFAULT": {"EXPID": "a01b", "HPCARCH": "ecmwf-hpc2020", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": "auto-ecearth4"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/es/auto-ecearth4", "PROJECT_BRANCH": "trunk", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true, "SOURCES_REPO": "e7988/ecearth4/-/tree/developments_bsc_autosubmit"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}}');
INSERT INTO experiment_run VALUES(31,'2023-09-12-15:26:01','2023-09-12-15:26:02',1694525161,1694525162,'month',1,0,4,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.89", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "JOBS": {"SYNCHRONIZE": {"FILE": "templates/synchronize.tmpl.sh", "WALLCLOCK": "01:00", "EC_QUEUE": "ecs", "RUNNING": "once", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.tmpl.sh", "DEPENDENCIES": {"SYNCHRONIZE": {}}, "WALLCLOCK": "01:00", "EC_QUEUE": "ecs", "RUNNING": "once", "ADDITIONAL_FILES": []}, "SIM": {"FILE": "templates/sim.tmpl.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}, "SIM-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "01:00", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROJECT": "bsc32", "USER": "bsc32070", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch", "PROJECT": "bsc32", "USER": "bsc32070"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "QUEUE": "bsc_es", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "ecs", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJ_DIR": "", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread", "PROJECT": "spesiccf"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01b", "PROJDIR": "/home/dbeltran/new_autosubmit/a01b/proj/project_files", "DEFAULT": {"EXPID": "a01b", "HPCARCH": "ecmwf-hpc2020", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": "auto-ecearth4"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/es/auto-ecearth4", "PROJECT_BRANCH": "trunk", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true, "SOURCES_REPO": "e7988/ecearth4/-/tree/developments_bsc_autosubmit"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}}');
INSERT INTO experiment_run VALUES(32,'2023-09-12-15:26:02','2023-09-12-15:31:59',1694525162,1694525519,'month',1,2,4,0,1,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.89", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "JOBS": {"SYNCHRONIZE": {"FILE": "templates/synchronize.tmpl.sh", "WALLCLOCK": "01:00", "EC_QUEUE": "ecs", "RUNNING": "once", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.tmpl.sh", "DEPENDENCIES": {"SYNCHRONIZE": {}}, "WALLCLOCK": "01:00", "EC_QUEUE": "ecs", "RUNNING": "once", "ADDITIONAL_FILES": []}, "SIM": {"FILE": "templates/sim.tmpl.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}, "SIM-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "01:00", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROJECT": "bsc32", "USER": "bsc32070", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch", "PROJECT": "bsc32", "USER": "bsc32070"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "QUEUE": "bsc_es", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "ecs", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJ_DIR": "", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread", "PROJECT": "spesiccf"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01b", "PROJDIR": "/home/dbeltran/new_autosubmit/a01b/proj/project_files", "DEFAULT": {"EXPID": "a01b", "HPCARCH": "ecmwf-hpc2020", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": "1", "NUMCHUNKS": "2", "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": "auto-ecearth4"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/es/auto-ecearth4", "PROJECT_BRANCH": "trunk", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true, "SOURCES_REPO": "e7988/ecearth4/-/tree/developments_bsc_autosubmit"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}}');
INSERT INTO experiment_run VALUES(33,'2023-09-12-15:31:59','2023-09-12-15:32:42',1694525519,1694525562,'month',1,0,4,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.89", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "JOBS": {"SYNCHRONIZE": {"FILE": "templates/synchronize.tmpl.sh", "WALLCLOCK": "01:00", "EC_QUEUE": "ecs", "RUNNING": "once", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.tmpl.sh", "DEPENDENCIES": {"SYNCHRONIZE": {}}, "WALLCLOCK": "01:00", "EC_QUEUE": "ecs", "RUNNING": "once", "ADDITIONAL_FILES": []}, "SIM": {"FILE": "templates/sim.tmpl.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}, "SIM-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "01:00", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROJECT": "bsc32", "USER": "bsc32070", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch", "PROJECT": "bsc32", "USER": "bsc32070"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "QUEUE": "bsc_es", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJ_DIR": "", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread", "PROJECT": "spesiccf"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01b", "PROJDIR": "/home/dbeltran/new_autosubmit/a01b/proj/project_files", "DEFAULT": {"EXPID": "a01b", "HPCARCH": "ecmwf-hpc2020", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": "auto-ecearth4"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/es/auto-ecearth4", "PROJECT_BRANCH": "trunk", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true, "SOURCES_REPO": "e7988/ecearth4/-/tree/developments_bsc_autosubmit"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}}');
INSERT INTO experiment_run VALUES(34,'2023-09-12-15:32:42','2023-09-12-15:33:10',1694525562,1694525590,'month',1,0,4,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.89", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "JOBS": {"SYNCHRONIZE": {"FILE": "templates/synchronize.tmpl.sh", "WALLCLOCK": "01:00", "EC_QUEUE": "ecs", "RUNNING": "once", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.tmpl.sh", "DEPENDENCIES": {"SYNCHRONIZE": {}}, "WALLCLOCK": "01:00", "EC_QUEUE": "ecs", "RUNNING": "once", "ADDITIONAL_FILES": []}, "SIM": {"FILE": "templates/sim.tmpl.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}, "SIM-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "01:00", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROJECT": "bsc32", "USER": "bsc32070", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch", "PROJECT": "bsc32", "USER": "bsc32070"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "QUEUE": "bsc_es", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJ_DIR": "", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread", "PROJECT": "spesiccf"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01b", "PROJDIR": "/home/dbeltran/new_autosubmit/a01b/proj/project_files", "DEFAULT": {"EXPID": "a01b", "HPCARCH": "ecmwf-hpc2020", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": "1", "NUMCHUNKS": "2", "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": "auto-ecearth4"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/es/auto-ecearth4", "PROJECT_BRANCH": "trunk", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true, "SOURCES_REPO": "e7988/ecearth4/-/tree/developments_bsc_autosubmit"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}}');
INSERT INTO experiment_run VALUES(35,'2023-09-12-15:33:10','2023-09-12-15:34:00',1694525590,1694525640,'month',1,0,4,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.89", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "JOBS": {"SYNCHRONIZE": {"FILE": "templates/synchronize.tmpl.sh", "WALLCLOCK": "01:00", "EC_QUEUE": "ecs", "RUNNING": "once", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.tmpl.sh", "DEPENDENCIES": {"SYNCHRONIZE": {}}, "WALLCLOCK": "01:00", "EC_QUEUE": "ecs", "RUNNING": "once", "ADDITIONAL_FILES": []}, "SIM": {"FILE": "templates/sim.tmpl.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}, "SIM-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "01:00", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROJECT": "bsc32", "USER": "bsc32070", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch", "PROJECT": "bsc32", "USER": "bsc32070"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "QUEUE": "bsc_es", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJ_DIR": "", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread", "PROJECT": "spesiccf"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01b", "PROJDIR": "/home/dbeltran/new_autosubmit/a01b/proj/project_files", "DEFAULT": {"EXPID": "a01b", "HPCARCH": "ecmwf-hpc2020", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": "auto-ecearth4"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/es/auto-ecearth4", "PROJECT_BRANCH": "trunk", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true, "SOURCES_REPO": "e7988/ecearth4/-/tree/developments_bsc_autosubmit"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}}');
INSERT INTO experiment_run VALUES(36,'2023-09-12-15:34:00','2023-09-12-15:38:49',1694525640,1694525929,'month',1,0,4,0,1,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.89", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "JOBS": {"SYNCHRONIZE": {"FILE": "templates/synchronize.tmpl.sh", "WALLCLOCK": "01:00", "EC_QUEUE": "ecs", "RUNNING": "once", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.tmpl.sh", "DEPENDENCIES": {"SYNCHRONIZE": {}}, "WALLCLOCK": "01:00", "EC_QUEUE": "ecs", "RUNNING": "once", "ADDITIONAL_FILES": []}, "SIM": {"FILE": "templates/sim.tmpl.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}, "SIM-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "01:00", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROJECT": "bsc32", "USER": "bsc32070", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch", "PROJECT": "bsc32", "USER": "bsc32070"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "QUEUE": "bsc_es", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJ_DIR": "", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread", "PROJECT": "spesiccf"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01b", "PROJDIR": "/home/dbeltran/new_autosubmit/a01b/proj/project_files", "DEFAULT": {"EXPID": "a01b", "HPCARCH": "ecmwf-hpc2020", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": "1", "NUMCHUNKS": "2", "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": "auto-ecearth4"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/es/auto-ecearth4", "PROJECT_BRANCH": "trunk", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true, "SOURCES_REPO": "e7988/ecearth4/-/tree/developments_bsc_autosubmit"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}}');
INSERT INTO experiment_run VALUES(37,'2023-09-12-15:38:49','2023-09-12-15:38:51',1694525929,1694525931,'month',1,0,4,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.89", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "JOBS": {"SYNCHRONIZE": {"FILE": "templates/synchronize.tmpl.sh", "WALLCLOCK": "01:00", "RUNNING": "once", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.tmpl.sh", "DEPENDENCIES": {"SYNCHRONIZE": {}}, "WALLCLOCK": "01:00", "EC_QUEUE": "ecs", "RUNNING": "once", "ADDITIONAL_FILES": []}, "SIM": {"FILE": "templates/sim.tmpl.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}, "SIM-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "01:00", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROJECT": "bsc32", "USER": "bsc32070", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch", "PROJECT": "bsc32", "USER": "bsc32070"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "QUEUE": "bsc_es", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJ_DIR": "", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread", "PROJECT": "spesiccf"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01b", "PROJDIR": "/home/dbeltran/new_autosubmit/a01b/proj/project_files", "DEFAULT": {"EXPID": "a01b", "HPCARCH": "ecmwf-hpc2020", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": "auto-ecearth4"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/es/auto-ecearth4", "PROJECT_BRANCH": "trunk", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true, "SOURCES_REPO": "e7988/ecearth4/-/tree/developments_bsc_autosubmit"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}}');
INSERT INTO experiment_run VALUES(38,'2023-09-12-15:38:51','2023-09-26-12:36:12',1694525931,1695724572,'month',1,4,4,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.89", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "JOBS": {"SYNCHRONIZE": {"FILE": "templates/synchronize.tmpl.sh", "WALLCLOCK": "01:00", "RUNNING": "once", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}, "REMOTE_SETUP": {"FILE": "templates/remote_setup.tmpl.sh", "DEPENDENCIES": {"SYNCHRONIZE": {}}, "WALLCLOCK": "01:00", "EC_QUEUE": "ecs", "RUNNING": "once", "ADDITIONAL_FILES": []}, "SIM": {"FILE": "templates/sim.tmpl.sh", "DEPENDENCIES": {"REMOTE_SETUP": {}, "SIM-1": {}}, "RUNNING": "chunk", "WALLCLOCK": "01:00", "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROJECT": "bsc32", "USER": "bsc32070", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch", "PROJECT": "bsc32", "USER": "bsc32070"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "QUEUE": "bsc_es", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJ_DIR": "", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread", "PROJECT": "spesiccf"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01b", "PROJDIR": "/home/dbeltran/new_autosubmit/a01b/proj/project_files", "DEFAULT": {"EXPID": "a01b", "HPCARCH": "ecmwf-hpc2020", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": "1", "NUMCHUNKS": "2", "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "none", "PROJECT_DESTINATION": "auto-ecearth4"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/es/auto-ecearth4", "PROJECT_BRANCH": "trunk", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true, "SOURCES_REPO": "e7988/ecearth4/-/tree/developments_bsc_autosubmit"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}}');
INSERT INTO experiment_run VALUES(39,'2023-09-26-12:36:12','2023-09-26-12:36:52',1695724572,1695724612,'month',1,0,0,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.92", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "JOBS": {"REMOTE_SETUP": {"FILE": "test.sh", "DEPENDENCIES": {"SYNCHRONIZE": {}}, "WALLCLOCK": "01:00", "EC_QUEUE": "ecs", "RUNNING": "once", "ADDITIONAL_FILES": ["test.yml"]}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROJECT": "bsc32", "USER": "bsc32070", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch", "PROJECT": "bsc32", "USER": "bsc32070"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "QUEUE": "bsc_es", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJ_DIR": "", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread", "PROJECT": "spesiccf"}, "TEST-LOCAL": {"TYPE": "slurm", "HOST": "localhost", "USER": "dbeltran", "PROJECT": "whatever", "SCRATCH_DIR": "/home/dbeltran"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01b", "PROJDIR": "/home/dbeltran/new_autosubmit/a01b/proj/project_files", "DEFAULT": {"EXPID": "a01b", "HPCARCH": "ecmwf-hpc2020", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "auto-ecearth4"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/es/auto-ecearth4", "PROJECT_BRANCH": "trunk", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true, "SOURCES_REPO": "e7988/ecearth4/-/tree/developments_bsc_autosubmit"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}}');
INSERT INTO experiment_run VALUES(40,'2023-09-26-12:36:52','2023-09-26-12:37:44',1695724612,1695724664,'month',1,0,1,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.92", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "JOBS": {"REMOTE_SETUP": {"FILE": "test.sh", "WALLCLOCK": "01:00", "EC_QUEUE": "ecs", "RUNNING": "once", "DEPENDENCIES": {}, "ADDITIONAL_FILES": ["test.yml"]}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROJECT": "bsc32", "USER": "bsc32070", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch", "PROJECT": "bsc32", "USER": "bsc32070"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "QUEUE": "bsc_es", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJ_DIR": "", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread", "PROJECT": "spesiccf"}, "TEST-LOCAL": {"TYPE": "slurm", "HOST": "localhost", "USER": "dbeltran", "PROJECT": "whatever", "SCRATCH_DIR": "/home/dbeltran"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01b", "PROJDIR": "/home/dbeltran/new_autosubmit/a01b/proj/project_files", "DEFAULT": {"EXPID": "a01b", "HPCARCH": "ecmwf-hpc2020", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "auto-ecearth4"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/es/auto-ecearth4", "PROJECT_BRANCH": "trunk", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true, "SOURCES_REPO": "e7988/ecearth4/-/tree/developments_bsc_autosubmit"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}}');
INSERT INTO experiment_run VALUES(41,'2023-09-26-12:37:44','2023-09-26-12:38:39',1695724664,1695724719,'month',1,0,1,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.92", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "JOBS": {"REMOTE_SETUP": {"FILE": "test.sh", "WALLCLOCK": "01:00", "EC_QUEUE": "ecs", "RUNNING": "once", "DEPENDENCIES": {}, "ADDITIONAL_FILES": ["test.yml"]}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROJECT": "bsc32", "USER": "bsc32070", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch", "PROJECT": "bsc32", "USER": "bsc32070"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "QUEUE": "bsc_es", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJ_DIR": "", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread", "PROJECT": "spesiccf"}, "TEST-LOCAL": {"TYPE": "slurm", "HOST": "localhost", "USER": "dbeltran", "PROJECT": "whatever", "SCRATCH_DIR": "/home/dbeltran"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01b", "PROJDIR": "/home/dbeltran/new_autosubmit/a01b/proj/project_files", "DEFAULT": {"EXPID": "a01b", "HPCARCH": "ecmwf-hpc2020", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "auto-ecearth4"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/es/auto-ecearth4", "PROJECT_BRANCH": "trunk", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true, "SOURCES_REPO": "e7988/ecearth4/-/tree/developments_bsc_autosubmit"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}}');
INSERT INTO experiment_run VALUES(42,'2023-09-26-12:38:39','2023-09-26-12:39:19',1695724719,1695724759,'month',1,0,1,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.92", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "JOBS": {"REMOTE_SETUP": {"FILE": "test.sh", "WALLCLOCK": "01:00", "EC_QUEUE": "ecs", "RUNNING": "once", "DEPENDENCIES": {}, "ADDITIONAL_FILES": []}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROJECT": "bsc32", "USER": "bsc32070", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch", "PROJECT": "bsc32", "USER": "bsc32070"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "QUEUE": "bsc_es", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJ_DIR": "", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread", "PROJECT": "spesiccf"}, "TEST-LOCAL": {"TYPE": "slurm", "HOST": "localhost", "USER": "dbeltran", "PROJECT": "whatever", "SCRATCH_DIR": "/home/dbeltran"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01b", "PROJDIR": "/home/dbeltran/new_autosubmit/a01b/proj/project_files", "DEFAULT": {"EXPID": "a01b", "HPCARCH": "ecmwf-hpc2020", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "auto-ecearth4"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/es/auto-ecearth4", "PROJECT_BRANCH": "trunk", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true, "SOURCES_REPO": "e7988/ecearth4/-/tree/developments_bsc_autosubmit"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}}');
INSERT INTO experiment_run VALUES(43,'2023-09-26-12:39:19','2023-09-26-12:39:44',1695724759,1695724784,'month',1,0,1,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.92", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "JOBS": {"REMOTE_SETUP": {"FILE": "test.sh", "WALLCLOCK": "01:00", "EC_QUEUE": "ecs", "RUNNING": "once", "DEPENDENCIES": {}, "ADDITIONAL_FILES": ["test.yml"]}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROJECT": "bsc32", "USER": "bsc32070", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch", "PROJECT": "bsc32", "USER": "bsc32070"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "QUEUE": "bsc_es", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJ_DIR": "", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread", "PROJECT": "spesiccf"}, "TEST-LOCAL": {"TYPE": "slurm", "HOST": "localhost", "USER": "dbeltran", "PROJECT": "whatever", "SCRATCH_DIR": "/home/dbeltran"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01b", "PROJDIR": "/home/dbeltran/new_autosubmit/a01b/proj/project_files", "DEFAULT": {"EXPID": "a01b", "HPCARCH": "ecmwf-hpc2020", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "auto-ecearth4"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/es/auto-ecearth4", "PROJECT_BRANCH": "trunk", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true, "SOURCES_REPO": "e7988/ecearth4/-/tree/developments_bsc_autosubmit"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}}');
INSERT INTO experiment_run VALUES(44,'2023-09-26-12:39:44','2023-09-26-12:43:26',1695724784,1695725006,'month',1,0,1,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.92", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "JOBS": {"REMOTE_SETUP": {"FILE": "test.sh", "WALLCLOCK": "01:00", "EC_QUEUE": "ecs", "RUNNING": "once", "DEPENDENCIES": {}, "ADDITIONAL_FILES": ["test.yml"]}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROJECT": "bsc32", "USER": "bsc32070", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch", "PROJECT": "bsc32", "USER": "bsc32070"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "QUEUE": "bsc_es", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJ_DIR": "", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread", "PROJECT": "spesiccf"}, "TEST-LOCAL": {"TYPE": "slurm", "HOST": "localhost", "USER": "dbeltran", "PROJECT": "whatever", "SCRATCH_DIR": "/home/dbeltran"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01b", "PROJDIR": "/home/dbeltran/new_autosubmit/a01b/proj/project_files", "DEFAULT": {"EXPID": "a01b", "HPCARCH": "ecmwf-hpc2020", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": "1", "NUMCHUNKS": "2", "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "auto-ecearth4"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/es/auto-ecearth4", "PROJECT_BRANCH": "trunk", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true, "SOURCES_REPO": "e7988/ecearth4/-/tree/developments_bsc_autosubmit"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}}');
INSERT INTO experiment_run VALUES(45,'2023-09-26-12:43:26','2023-09-26-12:43:46',1695725006,1695725026,'month',1,0,1,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.92", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "JOBS": {"REMOTE_SETUP": {"FILE": "test.sh", "WALLCLOCK": "01:00", "QUEUE": "debug", "PLATFORM": "marenostrum4", "RUNNING": "once", "DEPENDENCIES": {}, "ADDITIONAL_FILES": ["test.yml"]}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROJECT": "bsc32", "USER": "bsc32070", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch", "PROJECT": "bsc32", "USER": "bsc32070"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "QUEUE": "bsc_es", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJ_DIR": "", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread", "PROJECT": "spesiccf"}, "TEST-LOCAL": {"TYPE": "slurm", "HOST": "localhost", "USER": "dbeltran", "PROJECT": "whatever", "SCRATCH_DIR": "/home/dbeltran"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01b", "PROJDIR": "/home/dbeltran/new_autosubmit/a01b/proj/project_files", "DEFAULT": {"EXPID": "a01b", "HPCARCH": "ecmwf-hpc2020", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "auto-ecearth4"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/es/auto-ecearth4", "PROJECT_BRANCH": "trunk", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true, "SOURCES_REPO": "e7988/ecearth4/-/tree/developments_bsc_autosubmit"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}}');
INSERT INTO experiment_run VALUES(46,'2023-09-26-12:43:46','2023-09-26-12:45:10',1695725026,1695725110,'month',1,0,1,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.92", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "JOBS": {"REMOTE_SETUP": {"FILE": "test.sh", "WALLCLOCK": "01:00", "QUEUE": "debug", "PLATFORM": "marenostrum4", "RUNNING": "once", "DEPENDENCIES": {}, "ADDITIONAL_FILES": ["test.yml"]}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROJECT": "bsc32", "USER": "bsc32070", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch", "PROJECT": "bsc32", "USER": "bsc32070"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "QUEUE": "bsc_es", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJ_DIR": "", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread", "PROJECT": "spesiccf"}, "TEST-LOCAL": {"TYPE": "slurm", "HOST": "localhost", "USER": "dbeltran", "PROJECT": "whatever", "SCRATCH_DIR": "/home/dbeltran"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01b", "PROJDIR": "/home/dbeltran/new_autosubmit/a01b/proj/project_files", "DEFAULT": {"EXPID": "a01b", "HPCARCH": "ecmwf-hpc2020", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": "1", "NUMCHUNKS": "2", "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "auto-ecearth4"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/es/auto-ecearth4", "PROJECT_BRANCH": "trunk", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true, "SOURCES_REPO": "e7988/ecearth4/-/tree/developments_bsc_autosubmit"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}}');
INSERT INTO experiment_run VALUES(47,'2023-09-26-12:45:10','2023-09-26-12:45:30',1695725110,1695725130,'month',1,0,1,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.92", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "JOBS": {"REMOTE_SETUP": {"FILE": "test.sh", "WALLCLOCK": "01:00", "QUEUE": "debug", "PLATFORM": "marenostrum4", "RUNNING": "once", "DEPENDENCIES": {}, "ADDITIONAL_FILES": ["test.yml"]}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROJECT": "bsc32", "USER": "bsc32070", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch", "PROJECT": "bsc32", "USER": "bsc32070"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "QUEUE": "bsc_es", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJ_DIR": "", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread", "PROJECT": "spesiccf"}, "TEST-LOCAL": {"TYPE": "slurm", "HOST": "localhost", "USER": "dbeltran", "PROJECT": "whatever", "SCRATCH_DIR": "/home/dbeltran"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01b", "PROJDIR": "/home/dbeltran/new_autosubmit/a01b/proj/project_files", "DEFAULT": {"EXPID": "a01b", "HPCARCH": "ecmwf-hpc2020", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "auto-ecearth4"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/es/auto-ecearth4", "PROJECT_BRANCH": "trunk", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true, "SOURCES_REPO": "e7988/ecearth4/-/tree/developments_bsc_autosubmit"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}}');
INSERT INTO experiment_run VALUES(48,'2023-09-26-12:45:30','2023-09-26-12:48:42',1695725130,1695725322,'month',1,0,1,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.92", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "JOBS": {"REMOTE_SETUP": {"FILE": "test.sh", "WALLCLOCK": "01:00", "QUEUE": "debug", "PLATFORM": "marenostrum4", "RUNNING": "once", "DEPENDENCIES": {}, "ADDITIONAL_FILES": ["test.yml"]}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROJECT": "bsc32", "USER": "bsc32070", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch", "PROJECT": "bsc32", "USER": "bsc32070"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "QUEUE": "bsc_es", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJ_DIR": "", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread", "PROJECT": "spesiccf"}, "TEST-LOCAL": {"TYPE": "slurm", "HOST": "localhost", "USER": "dbeltran", "PROJECT": "whatever", "SCRATCH_DIR": "/home/dbeltran"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01b", "PROJDIR": "/home/dbeltran/new_autosubmit/a01b/proj/project_files", "DEFAULT": {"EXPID": "a01b", "HPCARCH": "ecmwf-hpc2020", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": "1", "NUMCHUNKS": "2", "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "auto-ecearth4"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/es/auto-ecearth4", "PROJECT_BRANCH": "trunk", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true, "SOURCES_REPO": "e7988/ecearth4/-/tree/developments_bsc_autosubmit"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}}');
INSERT INTO experiment_run VALUES(49,'2023-09-26-12:48:42','2023-09-26-12:49:01',1695725322,1695725341,'month',1,0,1,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.92", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "JOBS": {"REMOTE_SETUP": {"FILE": "test.sh", "WALLCLOCK": "01:00", "EC_QUEUE": "ecs", "RUNNING": "once", "DEPENDENCIES": {}, "ADDITIONAL_FILES": ["test.yml"]}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROJECT": "bsc32", "USER": "bsc32070", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch", "PROJECT": "bsc32", "USER": "bsc32070"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "QUEUE": "bsc_es", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJ_DIR": "", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread", "PROJECT": "spesiccf"}, "TEST-LOCAL": {"TYPE": "slurm", "HOST": "localhost", "USER": "dbeltran", "PROJECT": "whatever", "SCRATCH_DIR": "/home/dbeltran"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01b", "PROJDIR": "/home/dbeltran/new_autosubmit/a01b/proj/project_files", "DEFAULT": {"EXPID": "a01b", "HPCARCH": "ecmwf-hpc2020", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "auto-ecearth4"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/es/auto-ecearth4", "PROJECT_BRANCH": "trunk", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true, "SOURCES_REPO": "e7988/ecearth4/-/tree/developments_bsc_autosubmit"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}}');
INSERT INTO experiment_run VALUES(50,'2023-09-26-12:49:01','2023-09-26-12:51:16',1695725341,1695725476,'month',1,0,1,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.92", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "JOBS": {"REMOTE_SETUP": {"FILE": "test.sh", "WALLCLOCK": "01:00", "EC_QUEUE": "ecs", "RUNNING": "once", "DEPENDENCIES": {}, "ADDITIONAL_FILES": ["test.yml"]}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROJECT": "bsc32", "USER": "bsc32070", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch", "PROJECT": "bsc32", "USER": "bsc32070"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "QUEUE": "bsc_es", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJ_DIR": "", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread", "PROJECT": "spesiccf"}, "TEST-LOCAL": {"TYPE": "slurm", "HOST": "localhost", "USER": "dbeltran", "PROJECT": "whatever", "SCRATCH_DIR": "/home/dbeltran"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01b", "PROJDIR": "/home/dbeltran/new_autosubmit/a01b/proj/project_files", "DEFAULT": {"EXPID": "a01b", "HPCARCH": "ecmwf-hpc2020", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": "1", "NUMCHUNKS": "2", "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "auto-ecearth4"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/es/auto-ecearth4", "PROJECT_BRANCH": "trunk", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true, "SOURCES_REPO": "e7988/ecearth4/-/tree/developments_bsc_autosubmit"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}}');
INSERT INTO experiment_run VALUES(51,'2023-09-26-12:51:16','2023-09-26-12:51:35',1695725476,1695725495,'month',1,0,1,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.92", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "JOBS": {"REMOTE_SETUP": {"FILE": "test.sh", "WALLCLOCK": "01:00", "EC_QUEUE": "ecs", "RUNNING": "once", "DEPENDENCIES": {}, "ADDITIONAL_FILES": ["test.yml"]}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROJECT": "bsc32", "USER": "bsc32070", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch", "PROJECT": "bsc32", "USER": "bsc32070"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "QUEUE": "bsc_es", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJ_DIR": "", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread", "PROJECT": "spesiccf"}, "TEST-LOCAL": {"TYPE": "slurm", "HOST": "localhost", "USER": "dbeltran", "PROJECT": "whatever", "SCRATCH_DIR": "/home/dbeltran"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01b", "PROJDIR": "/home/dbeltran/new_autosubmit/a01b/proj/project_files", "DEFAULT": {"EXPID": "a01b", "HPCARCH": "ecmwf-hpc2020", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "auto-ecearth4"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/es/auto-ecearth4", "PROJECT_BRANCH": "trunk", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true, "SOURCES_REPO": "e7988/ecearth4/-/tree/developments_bsc_autosubmit"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}}');
INSERT INTO experiment_run VALUES(52,'2023-09-26-12:51:35','2023-09-26-12:52:16',1695725495,1695725536,'month',1,0,1,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.92", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "JOBS": {"REMOTE_SETUP": {"FILE": "test.sh", "WALLCLOCK": "01:00", "EC_QUEUE": "ecs", "RUNNING": "once", "DEPENDENCIES": {}, "ADDITIONAL_FILES": ["test.yml"]}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROJECT": "bsc32", "USER": "bsc32070", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch", "PROJECT": "bsc32", "USER": "bsc32070"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "QUEUE": "bsc_es", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJ_DIR": "", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread", "PROJECT": "spesiccf"}, "TEST-LOCAL": {"TYPE": "slurm", "HOST": "localhost", "USER": "dbeltran", "PROJECT": "whatever", "SCRATCH_DIR": "/home/dbeltran"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01b", "PROJDIR": "/home/dbeltran/new_autosubmit/a01b/proj/project_files", "DEFAULT": {"EXPID": "a01b", "HPCARCH": "ecmwf-hpc2020", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": "1", "NUMCHUNKS": "2", "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "auto-ecearth4"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/es/auto-ecearth4", "PROJECT_BRANCH": "trunk", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true, "SOURCES_REPO": "e7988/ecearth4/-/tree/developments_bsc_autosubmit"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}}');
INSERT INTO experiment_run VALUES(53,'2023-09-26-12:52:16','2023-09-26-12:52:37',1695725536,1695725557,'month',1,0,1,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.92", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "JOBS": {"REMOTE_SETUP": {"FILE": "test.sh", "WALLCLOCK": "01:00", "EC_QUEUE": "ecs", "RUNNING": "once", "DEPENDENCIES": {}, "ADDITIONAL_FILES": ["test.yml"]}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROJECT": "bsc32", "USER": "bsc32070", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch", "PROJECT": "bsc32", "USER": "bsc32070"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "QUEUE": "bsc_es", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJ_DIR": "", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread", "PROJECT": "spesiccf"}, "TEST-LOCAL": {"TYPE": "slurm", "HOST": "localhost", "USER": "dbeltran", "PROJECT": "whatever", "SCRATCH_DIR": "/home/dbeltran"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01b", "PROJDIR": "/home/dbeltran/new_autosubmit/a01b/proj/project_files", "DEFAULT": {"EXPID": "a01b", "HPCARCH": "ecmwf-hpc2020", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "auto-ecearth4"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/es/auto-ecearth4", "PROJECT_BRANCH": "trunk", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true, "SOURCES_REPO": "e7988/ecearth4/-/tree/developments_bsc_autosubmit"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}}');
INSERT INTO experiment_run VALUES(54,'2023-09-26-12:52:37','2023-09-26-13:02:57',1695725557,1695726177,'month',1,0,1,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.92", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "JOBS": {"REMOTE_SETUP": {"FILE": "test.sh", "WALLCLOCK": "01:00", "EC_QUEUE": "ecs", "RUNNING": "once", "DEPENDENCIES": {}, "ADDITIONAL_FILES": ["test.yml"]}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROJECT": "bsc32", "USER": "bsc32070", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch", "PROJECT": "bsc32", "USER": "bsc32070"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "QUEUE": "bsc_es", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJ_DIR": "", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread", "PROJECT": "spesiccf"}, "TEST-LOCAL": {"TYPE": "slurm", "HOST": "localhost", "USER": "dbeltran", "PROJECT": "whatever", "SCRATCH_DIR": "/home/dbeltran"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01b", "PROJDIR": "/home/dbeltran/new_autosubmit/a01b/proj/project_files", "DEFAULT": {"EXPID": "a01b", "HPCARCH": "ecmwf-hpc2020", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": "1", "NUMCHUNKS": "2", "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "auto-ecearth4"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/es/auto-ecearth4", "PROJECT_BRANCH": "trunk", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true, "SOURCES_REPO": "e7988/ecearth4/-/tree/developments_bsc_autosubmit"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}}');
INSERT INTO experiment_run VALUES(55,'2023-09-26-13:02:57','2023-09-26-13:03:17',1695726177,1695726197,'month',1,0,1,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.92", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "JOBS": {"REMOTE_SETUP": {"FILE": "test.sh", "WALLCLOCK": "01:00", "EC_QUEUE": "ecs", "RUNNING": "once", "DEPENDENCIES": {}, "ADDITIONAL_FILES": ["test.yml"]}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROJECT": "bsc32", "USER": "bsc32070", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch", "PROJECT": "bsc32", "USER": "bsc32070"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "QUEUE": "bsc_es", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJ_DIR": "", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread", "PROJECT": "spesiccf"}, "TEST-LOCAL": {"TYPE": "slurm", "HOST": "localhost", "USER": "dbeltran", "PROJECT": "whatever", "SCRATCH_DIR": "/home/dbeltran"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01b", "PROJDIR": "/home/dbeltran/new_autosubmit/a01b/proj/project_files", "DEFAULT": {"EXPID": "a01b", "HPCARCH": "ecmwf-hpc2020", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "auto-ecearth4"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/es/auto-ecearth4", "PROJECT_BRANCH": "trunk", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true, "SOURCES_REPO": "e7988/ecearth4/-/tree/developments_bsc_autosubmit"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}}');
INSERT INTO experiment_run VALUES(56,'2023-09-26-13:03:17','2023-09-26-13:06:43',1695726197,1695726403,'month',1,0,1,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.92", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "JOBS": {"REMOTE_SETUP": {"FILE": "test.sh", "WALLCLOCK": "01:00", "EC_QUEUE": "ecs", "RUNNING": "once", "DEPENDENCIES": {}, "ADDITIONAL_FILES": ["test.yml"]}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROJECT": "bsc32", "USER": "bsc32070", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch", "PROJECT": "bsc32", "USER": "bsc32070"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "QUEUE": "bsc_es", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJ_DIR": "", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread", "PROJECT": "spesiccf"}, "TEST-LOCAL": {"TYPE": "slurm", "HOST": "localhost", "USER": "dbeltran", "PROJECT": "whatever", "SCRATCH_DIR": "/home/dbeltran"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01b", "PROJDIR": "/home/dbeltran/new_autosubmit/a01b/proj/project_files", "DEFAULT": {"EXPID": "a01b", "HPCARCH": "ecmwf-hpc2020", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": "1", "NUMCHUNKS": "2", "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "auto-ecearth4"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/es/auto-ecearth4", "PROJECT_BRANCH": "trunk", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true, "SOURCES_REPO": "e7988/ecearth4/-/tree/developments_bsc_autosubmit"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}}');
INSERT INTO experiment_run VALUES(57,'2023-09-26-13:06:43','2023-09-26-13:07:03',1695726403,1695726423,'month',1,0,1,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.92", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "JOBS": {"REMOTE_SETUP": {"FILE": "test.sh", "WALLCLOCK": "01:00", "EC_QUEUE": "ecs", "RUNNING": "once", "DEPENDENCIES": {}, "ADDITIONAL_FILES": ["test.yml"]}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROJECT": "bsc32", "USER": "bsc32070", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch", "PROJECT": "bsc32", "USER": "bsc32070"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "QUEUE": "bsc_es", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJ_DIR": "", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread", "PROJECT": "spesiccf"}, "TEST-LOCAL": {"TYPE": "slurm", "HOST": "localhost", "USER": "dbeltran", "PROJECT": "whatever", "SCRATCH_DIR": "/home/dbeltran"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01b", "PROJDIR": "/home/dbeltran/new_autosubmit/a01b/proj/project_files", "DEFAULT": {"EXPID": "a01b", "HPCARCH": "ecmwf-hpc2020", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "auto-ecearth4"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/es/auto-ecearth4", "PROJECT_BRANCH": "trunk", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true, "SOURCES_REPO": "e7988/ecearth4/-/tree/developments_bsc_autosubmit"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}}');
INSERT INTO experiment_run VALUES(58,'2023-09-26-13:07:03','2023-09-26-13:08:49',1695726423,1695726529,'month',1,0,1,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.92", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "JOBS": {"REMOTE_SETUP": {"FILE": "test.sh", "WALLCLOCK": "01:00", "EC_QUEUE": "ecs", "RUNNING": "once", "DEPENDENCIES": {}, "ADDITIONAL_FILES": ["test.yml"]}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROJECT": "bsc32", "USER": "bsc32070", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch", "PROJECT": "bsc32", "USER": "bsc32070"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "QUEUE": "bsc_es", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJ_DIR": "", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread", "PROJECT": "spesiccf"}, "TEST-LOCAL": {"TYPE": "slurm", "HOST": "localhost", "USER": "dbeltran", "PROJECT": "whatever", "SCRATCH_DIR": "/home/dbeltran"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01b", "PROJDIR": "/home/dbeltran/new_autosubmit/a01b/proj/project_files", "DEFAULT": {"EXPID": "a01b", "HPCARCH": "ecmwf-hpc2020", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": "1", "NUMCHUNKS": "2", "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "auto-ecearth4"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/es/auto-ecearth4", "PROJECT_BRANCH": "trunk", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true, "SOURCES_REPO": "e7988/ecearth4/-/tree/developments_bsc_autosubmit"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}}');
INSERT INTO experiment_run VALUES(59,'2023-09-26-13:08:49','2023-09-26-13:08:51',1695726529,1695726531,'month',1,0,1,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.92", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "JOBS": {"REMOTE_SETUP": {"FILE": "test.sh", "WALLCLOCK": "01:00", "EC_QUEUE": "ecs", "RUNNING": "once", "DEPENDENCIES": {}, "ADDITIONAL_FILES": ["test.yml"]}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROJECT": "bsc32", "USER": "bsc32070", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch", "PROJECT": "bsc32", "USER": "bsc32070"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "QUEUE": "bsc_es", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJ_DIR": "", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread", "PROJECT": "spesiccf"}, "TEST-LOCAL": {"TYPE": "slurm", "HOST": "localhost", "USER": "dbeltran", "PROJECT": "whatever", "SCRATCH_DIR": "/home/dbeltran"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01b", "PROJDIR": "/home/dbeltran/new_autosubmit/a01b/proj/project_files", "DEFAULT": {"EXPID": "a01b", "HPCARCH": "ecmwf-hpc2020", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "auto-ecearth4"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/es/auto-ecearth4", "PROJECT_BRANCH": "trunk", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true, "SOURCES_REPO": "e7988/ecearth4/-/tree/developments_bsc_autosubmit"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}}');
INSERT INTO experiment_run VALUES(60,'2023-09-26-13:08:51','2023-09-27-09:08:29',1695726531,1695798509,'month',1,1,1,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.92", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "JOBS": {"REMOTE_SETUP": {"FILE": "test.sh", "WALLCLOCK": "01:00", "EC_QUEUE": "ecs", "RUNNING": "once", "DEPENDENCIES": {}, "ADDITIONAL_FILES": ["test.yml"]}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROJECT": "bsc32", "USER": "bsc32070", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug"}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch", "PROJECT": "bsc32", "USER": "bsc32070"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "QUEUE": "bsc_es", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJ_DIR": "", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread", "PROJECT": "spesiccf"}, "TEST-LOCAL": {"TYPE": "slurm", "HOST": "localhost", "USER": "dbeltran", "PROJECT": "whatever", "SCRATCH_DIR": "/home/dbeltran"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01b", "PROJDIR": "/home/dbeltran/new_autosubmit/a01b/proj/project_files", "DEFAULT": {"EXPID": "a01b", "HPCARCH": "ecmwf-hpc2020", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": "1", "NUMCHUNKS": "2", "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "auto-ecearth4"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/es/auto-ecearth4", "PROJECT_BRANCH": "trunk", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true, "SOURCES_REPO": "e7988/ecearth4/-/tree/developments_bsc_autosubmit"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}}');
INSERT INTO experiment_run VALUES(61,'2023-09-27-09:08:29','2023-09-27-09:08:36',1695798509,1695798516,'month',1,0,1,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.93", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "JOBS": {"REMOTE_SETUP": {"FILE": "test.sh", "WALLCLOCK": "01:00", "EC_QUEUE": "ecs", "RUNNING": "once", "DEPENDENCIES": {}, "ADDITIONAL_FILES": ["test.yml"]}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROJECT": "bsc32", "USER": "bsc32070", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "2FA": true}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch", "PROJECT": "bsc32", "USER": "bsc32070"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "QUEUE": "bsc_es", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJ_DIR": "", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread", "PROJECT": "spesiccf"}, "TEST-LOCAL": {"TYPE": "slurm", "HOST": "localhost", "USER": "dbeltran", "PROJECT": "whatever", "SCRATCH_DIR": "/home/dbeltran"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01b", "PROJDIR": "/home/dbeltran/new_autosubmit/a01b/proj/project_files", "DEFAULT": {"EXPID": "a01b", "HPCARCH": "ecmwf-hpc2020", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "auto-ecearth4"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/es/auto-ecearth4", "PROJECT_BRANCH": "trunk", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true, "SOURCES_REPO": "e7988/ecearth4/-/tree/developments_bsc_autosubmit"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}}');
INSERT INTO experiment_run VALUES(62,'2023-09-27-09:08:36','2023-09-27-09:09:30',1695798516,1695798570,'month',1,0,1,0,1,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.93", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "JOBS": {"REMOTE_SETUP": {"FILE": "test.sh", "WALLCLOCK": "01:00", "EC_QUEUE": "ecs", "RUNNING": "once", "DEPENDENCIES": {}, "ADDITIONAL_FILES": ["test.yml"]}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROJECT": "bsc32", "USER": "bsc32070", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "2FA": true}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch", "PROJECT": "bsc32", "USER": "bsc32070"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "QUEUE": "bsc_es", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJ_DIR": "", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread", "PROJECT": "spesiccf"}, "TEST-LOCAL": {"TYPE": "slurm", "HOST": "localhost", "USER": "dbeltran", "PROJECT": "whatever", "SCRATCH_DIR": "/home/dbeltran"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01b", "PROJDIR": "/home/dbeltran/new_autosubmit/a01b/proj/project_files", "DEFAULT": {"EXPID": "a01b", "HPCARCH": "ecmwf-hpc2020", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "auto-ecearth4"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/es/auto-ecearth4", "PROJECT_BRANCH": "trunk", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true, "SOURCES_REPO": "e7988/ecearth4/-/tree/developments_bsc_autosubmit"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}}');
INSERT INTO experiment_run VALUES(63,'2023-09-27-09:09:30','2023-09-27-09:09:30',1695798570,0,'month',1,0,1,0,0,0,0,0,'{"CONFIG": {"AUTOSUBMIT_VERSION": "4.0.93", "MAXWAITINGJOBS": 20, "TOTALJOBS": 20, "SAFETYSLEEPTIME": 10, "RETRIALS": 0}, "MAIL": {"NOTIFICATIONS": false, "TO": null}, "STORAGE": {"TYPE": "pkl", "COPY_REMOTE_LOGS": true}, "JOBS": {"REMOTE_SETUP": {"FILE": "test.sh", "WALLCLOCK": "01:00", "EC_QUEUE": "ecs", "RUNNING": "once", "DEPENDENCIES": {}, "ADDITIONAL_FILES": ["test.yml"]}}, "PLATFORMS": {"MARENOSTRUM4": {"TYPE": "slurm", "HOST": "bsc", "QUEUE": "debug", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "MAX_WALLCLOCK": "48:00", "TEMP_DIR": "", "PROJECT": "bsc32", "USER": "bsc32070", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "2FA": true}, "TRANSFER_NODE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "ADD_PROJECT_TO_HOST": "false", "SCRATCH_DIR": "/gpfs/scratch", "PROJECT": "bsc32", "USER": "bsc32070"}, "TRANSFER_NODE_BSCEARTH000": {"TYPE": "ps", "HOST": "bscearth000", "ADD_PROJECT_TO_HOST": false, "QUEUE": "serial", "SCRATCH_DIR": "/esarchive/scratch"}, "NORD3": {"TYPE": "SLURM", "HOST": "nord1.bsc.es", "QUEUE": "bsc_es", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00"}, "ECMWF-HPC2020": {"TYPE": "ecaccess", "VERSION": "slurm", "HOST": "hpc-login", "QUEUE": "nf", "EC_QUEUE": "hpc", "BUDGET": null, "USER": "c3d", "SCRATCH_DIR": "/ec/res4/scratch/c3d", "PROJ_DIR": "", "ADD_PROJECT_TO_HOST": false, "MAX_WALLCLOCK": "48:00", "CUSTOM_DIRECTIVES": "#SBATCH --hint=nomultithread", "PROJECT": "spesiccf"}, "TEST-LOCAL": {"TYPE": "slurm", "HOST": "localhost", "USER": "dbeltran", "PROJECT": "whatever", "SCRATCH_DIR": "/home/dbeltran"}, "POWER9": {"TYPE": "slurm", "HOST": "plogin1.bsc.es", "USER": "bsc32070", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "QUEUE": "debug"}, "LEVANTE": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work"}, "LEVANTE-LOGIN": {"TYPE": "slurm", "HOST": "levante.dkrz.de", "USER": "b382351", "PROJECT": "bb1153", "SCRATCH_DIR": "/work", "PARTITION": "interactive"}, "MARENOSTRUM0": {"TYPE": "slurm", "HOST": "marenostrum0", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "MAX_WALLCLOCK": "48:00", "MAX_PROCESSORS": "2400", "PROCESSORS_PER_NODE": "48", "SERIAL_QUEUE": "debug", "QUEUE": "debug"}, "MARENOSTRUM_ARCHIVE": {"TYPE": "ps", "HOST": "dt01.bsc.es", "PROJECT": "bsc32", "USER": "bsc32070", "SCRATCH_DIR": "/gpfs/scratch", "ADD_PROJECT_TO_HOST": "False", "TEST_SUITE": "False"}}, "ROOTDIR": "/home/dbeltran/new_autosubmit/a01b", "PROJDIR": "/home/dbeltran/new_autosubmit/a01b/proj/project_files", "DEFAULT": {"EXPID": "a01b", "HPCARCH": "ecmwf-hpc2020", "CUSTOM_CONFIG": {"POST": "~/platforms.yml"}}, "EXPERIMENT": {"DATELIST": "20000101", "MEMBERS": "fc0", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": 1, "NUMCHUNKS": 2, "CHUNKINI": "", "CALENDAR": "standard"}, "PROJECT": {"PROJECT_TYPE": "git", "PROJECT_DESTINATION": "auto-ecearth4"}, "GIT": {"PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/es/auto-ecearth4", "PROJECT_BRANCH": "trunk", "PROJECT_COMMIT": "", "PROJECT_SUBMODULES": "", "FETCH_SINGLE_BRANCH": true, "SOURCES_REPO": "e7988/ecearth4/-/tree/developments_bsc_autosubmit"}, "SVN": {"PROJECT_URL": "", "PROJECT_REVISION": ""}, "LOCAL": {"PROJECT_PATH": ""}, "PROJECT_FILES": {"FILE_PROJECT_CONF": "", "FILE_JOBS_CONF": "", "JOB_SCRIPTS_TYPE": ""}, "RERUN": {"RERUN": false, "RERUN_JOBLIST": ""}}');
CREATE TABLE job_data (
      id INTEGER NOT NULL PRIMARY KEY AUTOINCREMENT,
      counter INTEGER NOT NULL,
      job_name TEXT NOT NULL,
      created TEXT NOT NULL,
      modified TEXT NOT NULL,
      submit INTEGER NOT NULL,
      start INTEGER NOT NULL,
      finish INTEGER NOT NULL,
      status TEXT NOT NULL,
      rowtype INTEGER NOT NULL,
      ncpus INTEGER NOT NULL,
      wallclock TEXT NOT NULL,
      qos TEXT NOT NULL,
      energy INTEGER NOT NULL,
      date TEXT NOT NULL,
      section TEXT NOT NULL,
      member TEXT NOT NULL,
      chunk INTEGER NOT NULL,
      last INTEGER NOT NULL,
      platform TEXT NOT NULL,
      job_id INTEGER NOT NULL,
      extra_data TEXT NOT NULL,
      nnodes INTEGER NOT NULL DEFAULT 0,
      run_id INTEGER,
      MaxRSS REAL NOT NULL DEFAULT 0.0,
      AveRSS REAL NOT NULL DEFAULT 0.0,
      out TEXT NOT NULL,
      err TEXT NOT NULL,
      rowstatus INTEGER NOT NULL DEFAULT 0,
      children TEXT,
      platform_output TEXT,
      UNIQUE(counter,job_name)
      );
INSERT INTO job_data VALUES(1,0,'a01b_SYNCHRONIZE','2023-09-12-12:41:22','2023-09-12-13:28:52',1694515282,0,0,'SUBMITTED',2,1,'01:00','nf',0,'','SYNCHRONIZE','',0,0,'ECMWF-HPC2020',21733608,'',0,8,0.0,0.0,'','',0,'a01b_REMOTE_SETUP','');
INSERT INTO job_data VALUES(2,1,'a01b_SYNCHRONIZE','2023-09-12-13:28:52','2023-09-12-13:41:10',1694518132,1694518453,0,'FAILED',2,1,'01:00','nf',0,'','SYNCHRONIZE','',0,0,'ECMWF-HPC2020',21733634,'',0,21,0.0,0.0,'','',0,'a01b_REMOTE_SETUP','');
INSERT INTO job_data VALUES(3,2,'a01b_SYNCHRONIZE','2023-09-12-13:41:11','2023-09-12-13:42:56',1694518870,0,0,'SUBMITTED',2,1,'01:00','nf',0,'','SYNCHRONIZE','',0,0,'ECMWF-HPC2020',21733636,'',0,22,0.0,0.0,'','',0,'a01b_REMOTE_SETUP','');
INSERT INTO job_data VALUES(4,3,'a01b_SYNCHRONIZE','2023-09-12-13:42:56','2023-09-12-13:49:19',1694518976,1694519159,0,'RUNNING',2,1,'01:00','nf',0,'','SYNCHRONIZE','',0,0,'ECMWF-HPC2020',21733637,'',0,24,0.0,0.0,'','',0,'a01b_REMOTE_SETUP','');
INSERT INTO job_data VALUES(5,4,'a01b_SYNCHRONIZE','2023-09-12-13:49:19','2023-09-12-14:48:35',1694519359,0,0,'SUBMITTED',2,1,'01:00','nf',0,'','SYNCHRONIZE','',0,0,'ECMWF-HPC2020',21733640,'',0,26,0.0,0.0,'','',0,'a01b_REMOTE_SETUP','');
INSERT INTO job_data VALUES(6,5,'a01b_SYNCHRONIZE','2023-09-12-14:48:35','2023-09-12-15:19:27',1694522915,1694523186,1694523294,'FAILED',2,1,'01:00','nf',0,'','SYNCHRONIZE','',0,0,'ECMWF-HPC2020',21733748,'',0,29,0.0,0.0,'a01b_SYNCHRONIZE.20230912145306.out','a01b_SYNCHRONIZE.20230912145306.err',5,'a01b_REMOTE_SETUP','');
INSERT INTO job_data VALUES(7,6,'a01b_SYNCHRONIZE','2023-09-12-15:19:27','2023-09-12-15:26:13',1694524767,1694524793,1694524798,'COMPLETED',2,1,'01:00','nf',0,'','SYNCHRONIZE','',0,0,'ECMWF-HPC2020',21733775,'',0,30,0.0,0.0,'a01b_SYNCHRONIZE.20230912152311.out','a01b_SYNCHRONIZE.20230912152311.err',5,'a01b_REMOTE_SETUP','');
INSERT INTO job_data VALUES(8,6,'a01b_REMOTE_SETUP','2023-09-12-15:23:24','2023-09-12-15:27:57',1694525004,1694525015,0,'RUNNING',2,1,'01:00','nf',0,'','REMOTE_SETUP','',0,0,'ECMWF-HPC2020',21733776,'',0,30,0.0,0.0,'','',0,'a01b_20000101_fc0_1_SIM','');
INSERT INTO job_data VALUES(9,7,'a01b_SYNCHRONIZE','2023-09-12-15:26:13','2023-09-12-15:34:16',1694525173,1694525183,1694525188,'COMPLETED',2,1,'01:00','nf',0,'','SYNCHRONIZE','',0,0,'ECMWF-HPC2020',21733778,'',0,32,0.0,0.0,'a01b_SYNCHRONIZE.20230912152745.out','a01b_SYNCHRONIZE.20230912152745.err',5,'a01b_REMOTE_SETUP','');
INSERT INTO job_data VALUES(10,7,'a01b_REMOTE_SETUP','2023-09-12-15:27:57','2023-09-12-15:43:49',1694525277,1694525285,1694525290,'COMPLETED',2,1,'01:00','nf',0,'','REMOTE_SETUP','',0,0,'ECMWF-HPC2020',21733779,'',0,32,0.0,0.0,'a01b_REMOTE_SETUP.20230912153008.out','a01b_REMOTE_SETUP.20230912153008.err',5,'a01b_20000101_fc0_1_SIM','');
INSERT INTO job_data VALUES(11,7,'a01b_20000101_fc0_1_SIM','2023-09-12-15:30:26','2023-09-12-15:46:02',1694525426,0,0,'SUBMITTED',2,1,'01:00','nf',0,'2000-01-01 00:00:00','SIM','fc0',1,0,'ECMWF-HPC2020',21733780,'',0,32,0.0,0.0,'','',0,'a01b_20000101_fc0_2_SIM','');
INSERT INTO job_data VALUES(12,8,'a01b_SYNCHRONIZE','2023-09-12-15:34:16','2023-09-12-15:39:04',1694525656,1694525675,1694525680,'COMPLETED',2,1,'01:00','nf',0,'','SYNCHRONIZE','',0,0,'ECMWF-HPC2020',21733781,'',0,36,0.0,0.0,'a01b_SYNCHRONIZE.20230912153653.out','a01b_SYNCHRONIZE.20230912153653.err',5,'a01b_REMOTE_SETUP','');
INSERT INTO job_data VALUES(13,9,'a01b_SYNCHRONIZE','2023-09-12-15:39:04','2023-09-12-15:43:36',1694525944,1694525962,1694525967,'COMPLETED',2,1,'01:00','nf',0,'','SYNCHRONIZE','',0,1,'ECMWF-HPC2020',21733783,'',0,38,0.0,0.0,'a01b_SYNCHRONIZE.20230912154113.out','a01b_SYNCHRONIZE.20230912154113.err',5,'a01b_REMOTE_SETUP','');
INSERT INTO job_data VALUES(14,9,'a01b_REMOTE_SETUP','2023-09-12-15:43:49','2023-09-26-12:38:51',1694526229,1694526255,1694526260,'COMPLETED',2,1,'01:00','nf',0,'','REMOTE_SETUP','',0,0,'ECMWF-HPC2020',21733784,'',0,38,0.0,0.0,'a01b_REMOTE_SETUP.20230912154551.out','a01b_REMOTE_SETUP.20230912154551.err',5,'a01b_20000101_fc0_1_SIM','');
INSERT INTO job_data VALUES(15,9,'a01b_20000101_fc0_1_SIM','2023-09-12-15:46:02','2023-09-12-15:50:29',1694526362,1694526381,1694526386,'COMPLETED',2,1,'01:00','nf',0,'2000-01-01 00:00:00','SIM','fc0',1,1,'ECMWF-HPC2020',21733786,'',0,38,0.0,0.0,'a01b_20000101_fc0_1_SIM.20230912154800.out','a01b_20000101_fc0_1_SIM.20230912154800.err',5,'a01b_20000101_fc0_2_SIM','');
INSERT INTO job_data VALUES(16,9,'a01b_20000101_fc0_2_SIM','2023-09-12-15:50:44','2023-09-12-15:54:54',1694526644,1694526660,1694526665,'COMPLETED',2,1,'01:00','nf',0,'2000-01-01 00:00:00','SIM','fc0',2,1,'ECMWF-HPC2020',21733788,'',0,38,0.0,0.0,'a01b_20000101_fc0_2_SIM.20230912155229.out','a01b_20000101_fc0_2_SIM.20230912155229.err',5,'','');
INSERT INTO job_data VALUES(17,10,'a01b_REMOTE_SETUP','2023-09-26-12:38:51','2023-09-26-13:09:09',1695724731,0,0,'SUBMITTED',2,1,'01:00','nf',0,'','REMOTE_SETUP','',0,0,'ECMWF-HPC2020',21761502,'',0,42,0.0,0.0,'','',0,'','');
INSERT INTO job_data VALUES(18,11,'a01b_REMOTE_SETUP','2023-09-26-13:09:09','2023-09-27-09:08:49',1695726549,1695726562,1695726567,'COMPLETED',2,1,'01:00','nf',0,'','REMOTE_SETUP','',0,0,'ECMWF-HPC2020',21761507,'',0,60,0.0,0.0,'a01b_REMOTE_SETUP.20230926131041.out','a01b_REMOTE_SETUP.20230926131041.err',5,'','');
INSERT INTO job_data VALUES(19,12,'a01b_REMOTE_SETUP','2023-09-27-09:08:49','2023-09-27-09:08:49',1695798529,0,0,'SUBMITTED',2,1,'01:00','nf',0,'','REMOTE_SETUP','',0,1,'ECMWF-HPC2020',21763162,'',0,62,0.0,0.0,'','',0,'','');
DELETE FROM sqlite_sequence;
INSERT INTO sqlite_sequence VALUES('experiment_run',63);
INSERT INTO sqlite_sequence VALUES('job_data',19);
CREATE INDEX ID_JOB_NAME ON job_data(job_name);
COMMIT;
